@@ -1,7 +1,8 @@
 import sys
 
+import six
+
 from django.core.exceptions import ImproperlyConfigured
-from django.utils import six
 
 from .utils import import_attribute
 
@@ -115,7 +116,7 @@ class AppConf(six.with_metaclass(AppConfMetaClass)):
             setattr(self, name, value)
 
     def __dir__(self):
-        return sorted(list(set(self._meta.names.keys())))
+        return sorted(set(self._meta.names.keys()))
 
     # For instance access..
     @property
